==> haskell-xdg-desktop-entry-0.1.1.2-104-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-xdg-desktop-entry.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 xdg-desktop-entry
version:              0.1.1.2
visibility:           public
id:                   xdg-desktop-entry-0.1.1.2-9qOWomoXaJADXkQn3gyGPA
key:                  xdg-desktop-entry-0.1.1.2-9qOWomoXaJADXkQn3gyGPA
license:              BSD-3-Clause
maintainer:           IvanMalison@gmail.com
author:               Ivan Malison
homepage:             https://github.com/taffybar/xdg-desktop-entry
synopsis:             Parse files conforming to the xdg desktop entry spec
description:          Parse files conforming to the xdg desktop entry spec.
category:             System
abi:                  efda5d68826c795307592697eda3027a
exposed:              True
exposed-modules:      System.Environment.XDG.DesktopEntry
import-dirs:          /usr/lib/ghc-9.4.8/site-local/xdg-desktop-entry-0.1.1.2
library-dirs:         /usr/lib/ghc-9.4.8/site-local/xdg-desktop-entry-0.1.1.2
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/xdg-desktop-entry-0.1.1.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-xdg-desktop-entry
hs-libraries:         HSxdg-desktop-entry-0.1.1.2-9qOWomoXaJADXkQn3gyGPA
depends:
    base-4.17.2.1 directory-1.3.7.1 either-5.0.3-XHTPzGYQ146hY1b6mRqdU
    filepath-1.4.2.2 ini-0.4.2-9h31xFvHKYsFYr0BrWB1vP
    multimap-1.2.1-IfPJLlwBCWEIVO8zC2m8uz
    safe-0.3.21-8UNW4gIoNRmKgGFufdPOla text-2.0.2 transformers-0.5.6.2
    unix-2.7.3 unordered-containers-0.2.20-BdnqkwZm9bx6ocoMK9HG74

haddock-interfaces:
    /usr/share/doc/haskell-xdg-desktop-entry/html/xdg-desktop-entry.haddock

haddock-html:         /usr/share/doc/haskell-xdg-desktop-entry/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-xdg-desktop-entry-0.1.1.2-105-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-xdg-desktop-entry.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 xdg-desktop-entry
version:              0.1.1.2
visibility:           public
id:                   xdg-desktop-entry-0.1.1.2-FyVx3FB7SjT4i7lMRNZFAd
key:                  xdg-desktop-entry-0.1.1.2-FyVx3FB7SjT4i7lMRNZFAd
license:              BSD-3-Clause
maintainer:           IvanMalison@gmail.com
author:               Ivan Malison
homepage:             https://github.com/taffybar/xdg-desktop-entry
synopsis:             Parse files conforming to the xdg desktop entry spec
description:          Parse files conforming to the xdg desktop entry spec.
category:             System
abi:                  532c9ab029d35edd33a40ddb040ab504
exposed:              True
exposed-modules:      System.Environment.XDG.DesktopEntry
import-dirs:          /usr/lib/ghc-9.4.8/site-local/xdg-desktop-entry-0.1.1.2
library-dirs:         /usr/lib/ghc-9.4.8/site-local/xdg-desktop-entry-0.1.1.2
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/xdg-desktop-entry-0.1.1.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-xdg-desktop-entry
hs-libraries:         HSxdg-desktop-entry-0.1.1.2-FyVx3FB7SjT4i7lMRNZFAd
depends:
    base-4.17.2.1 directory-1.3.7.1 either-5.0.3-Dt1znj70bMfI4ry68g47tW
    filepath-1.4.2.2 ini-0.4.2-2hL4nC8oTUS2jy1pUiTUzu
    multimap-1.2.1-IfPJLlwBCWEIVO8zC2m8uz
    safe-0.3.21-29OHNU5kqwB6czdAzMhG9H text-2.0.2 transformers-0.5.6.2
    unix-2.7.3 unordered-containers-0.2.20-5YE9FG6zPmjDjdA4DCPpEY

haddock-interfaces:
    /usr/share/doc/haskell-xdg-desktop-entry/html/xdg-desktop-entry.haddock

haddock-html:         /usr/share/doc/haskell-xdg-desktop-entry/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
